@ECHO OFF
REM ****************************************************
REM *                   VERCHK.BAT                     *
REM *           Version Check Script File              *
REM *    Checks the version of SSA, LWA and QIA key    *
REM *     components and identifies mismatches.        *
REM *              (c) Vern Graner SSE                 *
REM ****************************************************
 REM * v1.0a Created 04/09/11 - VLG                     *
 REM * v1.0b Updated 09/12/11 - VLG Chk multi paths     *
 REM * v1.0c updated 09/26/11 - External Rev Strings    *
 REM * v1.0d updated 10/03/11 - include CWD             *
 REM * v1.0e updated 10/04/11 - check installed copy    *
 REM * v1.0f updated 10/04/11 - reorder paths           *
 REM * v1.0g updated 10/19/11 - add DSRR4104 check      *
 REM * v1.0h updated 03/12/12 - add STAD0.DLL check     *
 REM * v1.0i updated 03/13/12 - fix win7 MSI ver bug    *
 REM * v1.0j updated 03/14/12 - fix STAD var bug        *
 REM * v1.1a updated 03/13/12 - internet fetch option   *
 REM * v1.1b updated 03/16/12 - output format change    *
 REM * v1.1c updated 03/21/12 - add switches for tests  *
 REM * v1.1d updated 03/21/12 - add BUILD.TXT option    *
 REM * v1.1e updated 04/30/12 - add QI/ST console check *
 REM * v1.1f updated 05/01/12 - add US/EU switch        *
 REM * v1.1g updated 05/01/12 - fixed embedded RefBuild *
 REM * v1.1h updated 05/01/12 - auto-update buildref    *
 REM * v1.1i updated 07/11/12 - check NT4 SSA component *
 REM * v1.1j updated 12/12/12 - vbs use WinHttp fetch   *
 REM * v1.1k updated 12/18/12 - fix QIA MSI ver on W7/8 *
 REM * v1.2b updated 12/20/12 - add parameter passing   *
 REM * v1.2c updated 01/24/13 - add LWA-QIA-UPDATE chk  *
 REM * v1.2d updated 02/05/13 - add auto date format    *
 REM * v1.2e updated 02/07/13 - small date format fix   *
 REM * v1.2f updated 02/07/13 - new console check       *
 REM * v1.2g updated 07/11/13 - fix (x86) path issue    *
 REM * v1.2h updated 09/17/13 - add \. check for SSA    *
 REM * v1.2i updated 09/23/13 - add Build out for SSA   *
 REM * v1.2j updated 09/23/13 - add STVIEW2K.WKS test   *
 REM * v1.2k updated 09/23/13 - Put SSA in one block    *
 REM * v1.2l updated 12/04/13 - add chk SOFTRACK.NLM 5  *
 REM * v1.2m updated 01/06/14 - add OS Version/Bitwidth *
 REM * v1.2n updated 08/30/16 - fix ST2K_RPT.EXE check  *
 REM * v1.2o updated 07/14/17 - added md5 hash checker  *
 REM * v1.2p updated 03/05/18 - added LWATRAY checker   *
 REM * v1.2q updated 01/21/19 - added 64-bit components *
 REM * v1.2q updated 07/07/21 - detects .dll in syswow64 folder*
 REM ****************************************************
 REM * WARNING: The component versions MUST be updated  *
 REM * or verified before this script is run!           *
 REM ****************************************************
 REM * NOTE: This batch file should be run from the     *
 REM * root of the decompressed SOFTRACK_FULL dir or    *
 REM * the MSI-created "Integrity Software Inc" folder. *
 REM ****************************************************

REM ****************************************************
REM * Environment Setup                                *
REM ****************************************************
   REM Set color to white text on black background
     COLOR 0F

   REM Set variables to NOT exist when script finishes
   REM and enable Delayed Variable Expansion
   REM SetLocal EnableDelayedExpansion
     SetLocal

   REM Set script version
     SET ScriptVersion=v1.2q
     TITLE SofTrack Component Version Checker %ScriptVersion% by Vern Graner

   REM Set default test result
     SET "VerChkResult=PASS"

   REM Set paths for situations where the "real"
   REM Windows files are preceded with "fakes"
     SET PATH=%SystemRoot%;%SystemRoot%\SYSTEM32;%SystemRoot%\SYSTEM32\WBEM;%PATH%

   REM **********************************
   REM * Turn DEBUG on/off              *
   REM ******************************************************************************
   rem * The >nul 2>&1 redirects output and error output to nul to make clean runs  *
   rem * NOTE: The reserved characters are delimited with a "^" symbol to make them *
   rem * compatible with the "set" command, so ">nul 2>&1" becomes "^>nul 2^>^&1"   *
   rem * un-REM "SET DEBUG=" to have errors/output of commands displayed.           *
   REM ******************************************************************************
   SET DEBUG=^>nul 2^>^&1
   rem  SET DEBUG=

REM ****************************************************
REM * Settings to control operation                    *
REM ****************************************************

  REM **********************************
  REM * Path for LAN-based ref file    *
  REM **********************************
   SET "LanPath=%LogonServer%\sysvol\%UserDNSDomain%\scripts"
  
  REM **************************************
  REM * Allow fetch of updated version     *
  REM * definitions from internet server   *
  REM * Valid values are "Yes" and "No"    *
  REM * value is CASE SENSITITVE!          *
  REM * NOTE: do NOT place in quotes!      *
  REM **************************************
   SET InternetFetch=Yes

  REM **************************************
  REM * Test which CONSOLE components      *
  REM * Valid values are "Yes" and "No"    *
  REM * value is CASE SENSITITVE!          *
  REM * NOTE: do NOT place in quotes!      *
  REM **************************************
   SET TestConsole=Yes
   SET TestSSA=Yes
   SET TestLWA=Yes
   SET TestQIA=Yes
   SET TestMSI=No

  REM **************************************
  REM * Create BUILD.TXT for MSI inclusion *
  REM * Valid values are "Yes" and "No"    *
  REM * value is CASE SENSITITVE!          *
  REM * NOTE: do NOT place in quotes!      *
  REM **************************************
   SET CreateBuild=No

  REM **************************************
  REM * Check for parameter passed         *
  REM * overrides. Note:                   *
  REM * -Values are NOT case sensitive     *
  REM * -Do not place in quotes            *
  REM **************************************
  REM * Valid Parameters are:              *
  REM *   NoInternet                       *
  REM *   NoConsole                        *
  REM *   NoSSA                            *
  REM *   NoLWA                            *
  REM *   NoQIA                            *
  REM *   NoMSI                            *
  REM *   Build                            *
  REM *   Quiet                            *
  REM **************************************

  :ParameterLoop
  IF /I "%1."=="NoInternet." SET InternetFetch=No
  IF /I "%1."=="NoConsole." SET TestConsole=No
  IF /I "%1."=="NoSSA." SET TestSSA=No
  IF /I "%1."=="NoLWA." SET TestLWA=No
  IF /I "%1."=="NoQIA." SET TestQIA=No
  IF /I "%1."=="NoMSI." SET TestMSI=No
  IF /I "%1."=="Build." SET CreateBuild=Yes
  IF /I "%1."=="Quiet." SET SilentMode=Yes
  SHIFT
  IF NOT "%1"=="" GOTO ParameterLoop

REM ****************************************************
REM * Clean up leftover files                          *
REM ****************************************************
   DEL /Q %TEMP%\VerChk-Header.tmp %DEBUG%

REM ****************************************************
REM * Create Header Part 1                             *
REM ****************************************************
   ECHO SOFTRACK_FULL component Version check script %ScriptVersion% by Vern Graner >>%TEMP%\VerChk-Header.tmp
   ECHO --------------------------------------------------------------------------- >>%TEMP%\VerChk-Header.tmp
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

REM ****************************************************
REM * Fetch Date/Time                                  *
REM ****************************************************
   IF NOT "%SilentMode%." =="Yes." ECHO   This Report Created: Reading Time Date info..

   REM Extract the output of DATE command and store values
   FOR /F "tokens=1-4 delims=/ " %%i in ('DATE /T') do (
     SET Val1=%%i
     SET Val2=%%j
     SET Val3=%%k
     SET Val4=%%l
   )

   REM Query Registry key for Date Format: 0=MM/DD/YYYY 1=DD/MM/YYYY
   FOR /F "tokens=3" %%A IN ('REG QUERY "HKCU\Control Panel\International" /v iDate 2^>NUL') DO (SET DateFormat=%%A)

   REM Check for and remove leading "day of the week" if present
   IF "%Val4%." == "." (
     REM No Leading Day to skip
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val1=DD Val2=MM Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val2%-%Val1%
     ) ELSE (
       rem  FORMAT Val1=MM Val2=DD Val3=YYYY
       set MyDate=%Val1%/%Val2%/%Val3%
       set FileDate=%Val3%-%Val1%-%Val2%
     )
   ) ELSE (
     REM Skip over Leading Day
     IF "%DateFormat%."=="1." (
       rem  FORMAT Val2=DD Val3=MM Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val3%-%Val2%
     ) ELSE (
       rem  FORMAT Val2=MM Val3=DD Val4=YYYY
       set MyDate=%Val2%/%Val3%/%Val4%
       set FileDate=%Val4%-%Val2%-%Val3%
     )
   )

   REM Fetching time and placing values in variables
   FOR /F "tokens=1-3 delims=: " %%l in ('TIME /T') do (
     SET Val1=%%l
     SET Val2=%%m
     SET Val3=%%n
   )

   rem Check to see if AM/PM is populated- If so, do "HH:MM AM/PM"
   rem if not, skip and do Military Time format: "HH:MM"
   IF "%Val3%."=="." (
     set MyTime=%Val1%:%Val2%
     set FileTime=%Val1%-%Val2%
   ) ELSE (
     set MyTime=%Val1%:%Val2% %Val3%
     set FileTime=%Val1%-%Val2%-%Val3%
   )

   SET TimeStamp=%MyDate% %MyTime%

REM ****************************************************
REM * Check if we should create BUILD.TXT              *
REM ****************************************************
   IF "%CreateBuild%"=="Yes" (
     SET CreateBuild=BUILD.TXT
   ) ELSE (
     SET CreateBuild=NUL
   )

REM ****************************************************
REM * Lookup OS version and bit width                  *
REM ****************************************************

   REM Use WMIC command to fetch OS caption (name)
   REM DEcided not to use this more accurate one to
   rem avoid possibility of WMIC hanging up
rem    FOR /f "tokens=1-4 delims= " %%i in ('WMIC OS Get Caption ^<nul ^| find "Microsoft"') do set OSVersion=%%i %%j %%k %%l
rem   DEL /Q TempWmicBatchFile.bat %DEBUG%

   REM Determine Windows OS version using system variables 
   for /f "tokens=1-2 delims=[]" %%i in ('ver') do set OSVer=%%j
   rem Remove the word "version" from the result
   FOR /F "tokens=1-2 delims= " %%i in ('echo %%OSVer%%') do (SET OSVer=%%j)
   rem Lookup the version string in table for "friendly" name
   SET OSVersion=
   IF "%OSVer%."=="4.00.950." SET OSVersion=Windows 95
   IF "%OSVer%."=="4.00.1111." SET OSVersion=Windows 95 OSR2
   IF "%OSVer%."=="4.00.1381." SET OSVersion=Windows NT 4.0
   IF "%OSVer%."=="4.00.1381." SET OSVersion=Windows NT 4.0
   IF "%OSVer%."=="4.10.1998." SET OSVersion=Windows 98
   IF "%OSVer%."=="4.10.2222." SET OSVersion=Windows 98 SE
   IF "%OSVer%."=="4.90.3000." SET OSVersion=Windows ME
   IF "%OSVer%."=="5.00.2195." SET OSVersion=Windows 2000
   IF "%OSVer%."=="5.1.2600." SET OSVersion=Windows XP
   IF "%OSVer%."=="5.2.3790." SET OSVersion=Windows Server 2003
   IF "%OSVer%."=="6.0.6000." SET OSVersion=Windows Vista/Server 2008
   IF "%OSVer%."=="6.0.6002." SET OSVersion=Windows Vista SP2
   IF "%OSVer%."=="6.1.7600." SET OSVersion=Windows 7/Server 2008 R2
   IF "%OSVer%."=="6.1.7601." SET OSVersion=Windows 7 SP1/Server 2008 R2 SP1
   IF "%OSVer%."=="6.2.9200." SET OSVersion=Windows 8/Server 2012
   IF "%OSVer%."=="6.3.9600." SET OSVersion=Windows 8.1/Server 2012 R2
   REM If lookup fails, just use the version string
   IF "%OSVersion%."=="." SET OSVersion=%OSVer%
   REM Check the bit width- 32 or 64 bit

   IF "%PROCESSOR_ARCHITECTURE%."=="x86." (
     SET BitSize=32bit
   ) ELSE (
     SET BitSize=64bit
   )
   
REM ****************************************************
REM * Create Header Part 2                             *
REM ********************************************************************
REM                                                                     \
   ECHO   This Report Created: %TimeStamp% >>%TEMP%\VerChk-Header.tmp
   ECHO  Performed on Machine: %ComputerName% >>%TEMP%\VerChk-Header.tmp
   ECHO            OS Version: %OSVer% [%OSVersion% %BitSize%] >>%TEMP%\VerChk-Header.tmp
   ECHO  Run on components at: %CD% >>%TEMP%\VerChk-Header.tmp
   
REM                                                                     /
REM ********************************************************************

REM ****************************************************
REM * Get VerChk_RefBuild.txt for version testing      *
REM ********************************************************************
REM                                                                     \
   REM Make sure any existing version file is deleted
   IF EXIST %temp%\VerChk_RefBuild.txt DEL /Q %temp%\VerChk_RefBuild.txt %DEBUG%

   REM to see if Internet access is allowed
   IF "%InternetFetch%"=="No" Goto Skip-IUpdate
   
   REM **********************************
   REM * Build and run WebFetch Script  *
   REM *************************************************
   REM                                                  \
   
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
	 ECHO    Reference Versions: Seeking via HTTP..   
   )
   
   SET VerPath=http://209.59.135.5/count/VerChk_RefBuild.txt
   REM SET VerPath=http://209.59.135.5/~wwwvisu/guestftpdir/VerChk_RefBuild.txt

   DEL /Q %temp%\FetchUpdate.vbs %DEBUG%

   ECHO strFileURL = "%VerPath%">%temp%\FetchUpdate.vbs
   ECHO strHDLocation = "%temp%\VerChk_RefBuild.txt">>%temp%\FetchUpdate.vbs
   ECHO Set objXMLHTTP = CreateObject("WinHttp.WinHttpRequest.5.1")>>%temp%\FetchUpdate.vbs
   ECHO objXMLHTTP.open "GET", strFileURL, false>>%temp%\FetchUpdate.vbs
   ECHO objXMLHTTP.send()>>%temp%\FetchUpdate.vbs
   ECHO If objXMLHTTP.Status = 200 Then>>%temp%\FetchUpdate.vbs
   ECHO Set objADOStream = CreateObject("ADODB.Stream")>>%temp%\FetchUpdate.vbs
   ECHO objADOStream.Open>>%temp%\FetchUpdate.vbs
   ECHO objADOStream.Type = 1 'adTypeBinary>>%temp%\FetchUpdate.vbs
   ECHO objADOStream.Write objXMLHTTP.ResponseBody>>%temp%\FetchUpdate.vbs
   ECHO objADOStream.Position = 0    'Set the stream position to the start>>%temp%\FetchUpdate.vbs
   ECHO Set objFSO = Createobject("Scripting.FileSystemObject")>>%temp%\FetchUpdate.vbs
   ECHO If objFSO.Fileexists(strHDLocation) Then objFSO.DeleteFile strHDLocation>>%temp%\FetchUpdate.vbs
   ECHO Set objFSO = Nothing>>%temp%\FetchUpdate.vbs
   ECHO objADOStream.SaveToFile strHDLocation>>%temp%\FetchUpdate.vbs
   ECHO objADOStream.Close>>%temp%\FetchUpdate.vbs
   ECHO Set objADOStream = Nothing>>%temp%\FetchUpdate.vbs
   ECHO End if>>%temp%\FetchUpdate.vbs
   ECHO Set objXMLHTTP = Nothing>>%temp%\FetchUpdate.vbs

   REM Script built, now launch it
   CSCRIPT //B //t:120 %temp%\FetchUpdate.vbs

   If NOT Exist "%temp%\VerChk_RefBuild.txt" GOTO WebFetchFail

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )
   IF NOT "%SilentMode%." =="Yes." ECHO    Reference Versions: Parsing Build Definitions
   FOR /F "tokens=*" %%i in ('type "%temp%\VerChk_RefBuild.txt"') do SET %%i

   DEL /Q %temp%\VerChk_RefBuild.txt %DEBUG%
   DEL /Q %temp%\FetchUpdate.vbs %DEBUG%

   IF NOT "%UPDATED%."=="." GOTO VerDone
   :WebFetchFail
   REM                                                 /
   REM *************************************************

   REM **********************************
   REM * Build and run FTP fetch script *
   REM * deprecated due to u/p required *
   REM * as visible in script           *
   REM *************************************************
   REM                                                  \
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
	 ECHO    Reference Versions: Seeking via FTP..
   )

   rem These values are for Integrity Software Inc FTP site
   SET FTPAltPort=23
   SET BINtype=ftp
   SET FTPmode=guest
   SET FTPType=Anonymous
   SET FTPSource=visualclick.com
   SET VerPath=209.59.135.5

   > %temp%\FetchUpdate.ftp ECHO %FTPmode%@%FTPsource%
   >>%temp%\FetchUpdate.ftp ECHO %BINtype%files%FTPAltPort%
   >>%temp%\FetchUpdate.ftp ECHO lcd %temp%
   >>%temp%\FetchUpdate.ftp ECHO get VerChk_RefBuild.txt
   >>%temp%\FetchUpdate.ftp ECHO quit

   FTP -v -i -s:%temp%\FetchUpdate.ftp %VerPath% %DEBUG%
   DEL %temp%\FetchUpdate.ftp %DEBUG%

   If NOT Exist "%temp%\VerChk_RefBuild.txt" GOTO FTPFetchFail

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )
   IF NOT "%SilentMode%." =="Yes." ECHO    Reference Versions: Parsing Build Definitions..
   FOR /F "tokens=*" %%i in ('type "%temp%\VerChk_RefBuild.txt"') do SET %%i

   DEL /Q %temp%\FetchUpdate.ftp %DEBUG%
   DEL /Q %temp%\VerChk_RefBuild.txt %DEBUG%
   SET VerPath=Fetched via FTP from "%VerPath%"

   IF NOT "%UPDATED%."=="." GOTO VerDone
   :FTPFetchFail
   REM                                                 /
   REM *************************************************

   REM **********************************
   REM * LAN server fetch               *
   REM *************************************************
   REM                                                  \
   :Skip-IUpdate

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
	 ECHO    Reference Versions: Seeking via LAN path..
   )

   SET VerPath=%LanPath%
   If NOT Exist "%VerPath%\VerChk_RefBuild.txt" GOTO LANFetchFail

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )
   IF NOT "%SilentMode%." =="Yes." ECHO    Reference Versions: Parsing Build Definitions..
   FOR /F "tokens=*" %%i in ('type "%VerPath%\VerChk_RefBuild.txt"') do SET %%i
   SET VerPath=Fetched via LAN from "%VerPath%"

   IF NOT "%UPDATED%."=="." GOTO VerDone
   :LANFetchFail
   REM                                                 /
   REM *************************************************

   REM **********************************
   REM * Current Directory fetch        *
   REM *************************************************
   REM                                                  \
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
	 ECHO    Reference Versions: Seeking in Current Dir..
   )

   SET VerPath=%CD%
   If NOT Exist "%VerPath%\VerChk_RefBuild.txt" GOTO CWDFetchFail
   
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )
   ECHO    Reference Versions: Parsing Build Definitions..
   FOR /F "tokens=*" %%i in ('type "%VerPath%\VerChk_RefBuild.txt"') do SET %%i
   SET VerPath=Fetched via CWD from "%VerPath%"

   IF NOT "%UPDATED%."=="." GOTO VerDone
   :CWDFetchFail
   REM                                                 /
   REM ************************************************

   REM **********************************
   REM * These internal values used     *
   REM * only if NO external Build Ref  *
   REM * file can be located            *
   REM *************************************************
   REM                                                  \
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
	 ECHO    Reference Versions: Embedded
   )
   SET VerPath=Embedded
   SET VerChkResult=Warning! Internal revisions used!
   REM                                                  /
   REM *************************************************

   rem *****************************************
   rem * Set version from currently shipping   *
   rem * archive to identify mismatched        *
   rem * or older components.                  *
   rem *****************************************

   rem above is VC1.TXT
   rem CUT HERE =======================================================================
REM This version of VERCHK built 08/24/2016 07:50 AM 

SET UPDATED=2016-08-24
SET LWA-QIA-UPDATE-SHIP=v2.4f
SET VerChk-SHIP=v1.2m
SET SOFTRACK_CONSOLE-SHIP=V7.2xx
SET DSRR4104-SHIP=v7.40k
SET QIADMIN-SHIP=v6.92a
SET STDLL32-SHIP=v7.24a
SET STNT32-SHIP=v7.37u
SET STAD0-SHIP=v3.45c
SET ST2K_RPT-SHIP=v1.97a
SET STSRVC32-SHIP=v7.10e
SET STVIEW2K-SHIP=vX.76a
SET STVIEW2K-WKS-SHIP=N/A   
SET SOFTRACK-NLM5-SHIP=v6.64a
SET STSRVC64-SHIP=v8.14a
SET STVIEW64-SHIP=vX.30a
SET STAD0_64-SHIP=v4.01a
SET STLWA_NT-SHIP=v7.15g
SET STLWMON-SHIP=v6.56j
SET STBW_K32-SHIP=v6.80d
SET CPTLWA32-SHIP=v3.45z
SET STVISTA-SHIP=v3.25u
SET STBW_K64-SHIP=v6.80h
SET STLWA_64-SHIP=v3.94f
SET CPTLWA64-SHIP=v3.44z
SET CPT_X64A-SHIP=v3.39g
SET INVENTRY-SHIP=v2.5a
SET QISVC0-SHIP=v1.1h
SET LWASETUP-SHIP=04.20.2016.1
SET QIASETUP-SHIP=04.20.2016.1
SET LWATRAY-SHIP=v1.00a
   rem CUT HERE =======================================================================
   rem below is VC3.TXT

   :VerDone
REM                                                                     /
REM ********************************************************************

REM ****************************************************
REM * Create Header Part 3                             *
REM ****************************************************
   ECHO    Reference Versions: %VerPath%>>%TEMP%\VerChk-Header.tmp
   ECHO Reference Last Update: %UPDATED%>>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM Update the build.txt with a header
   TYPE %TEMP%\VerChk-Header.tmp >%CreateBuild%

REM ****************************************************
REM * SOFTRACK_FULL internal Build date                *
REM ****************************************************
   SET Internal=N/A
   IF EXIST BUILD.DAT (
     FOR /F "tokens=1-3 delims= " %%i in ('type build.dat') do set Internal=%%i %%j %%k
   )

   ECHO   SOFTRACK_FULL build: %Internal% >>%TEMP%\VerChk-Header.tmp
   ECHO. >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

REM ****************************************************
REM * Console Components Testing                       *
REM ********************************************************************
REM                                                                     \
   IF "%TestConsole%"=="No" GOTO NoTestConsole

   ECHO CONSOLE Versions: >>%TEMP%\VerChk-Header.tmp
   ECHO -------------------------------------+>>%TEMP%\VerChk-Header.tmp
   ECHO Component    ^| Ref    ^| Found  ^|Pass ^|Path >>%TEMP%\VerChk-Header.tmp
   ECHO -------------+--------+--------+-----+--------------------------------- >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing VerChk.bat                    *
   REM *****************************************
   SET Found=None
   IF EXIST %SystemDrive%\PROGRA~1\INTEGR~1\VerChk.bat SET Found=%SystemDrive%\PROGRA~1\INTEGR~1\
   IF EXIST %SystemDrive%\PROGRA~1\INTEGR~1\WORKST~1\VerChk.bat SET Found=%SystemDrive%\PROGRA~1\INTEGR~1\WORKST~1\
   IF EXIST SOFTRACK_FULL\VerChk.bat SET Found=SOFTRACK_FULL\
   IF EXIST VerChk.bat SET Found=.\

   IF "%Found%"=="None" (
     SET "VerChk-VER=N/A  "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-VerChk
   )

   IF NOT "%SilentMode%." =="Yes." ECHO VerChk.bat   ^| %VerChk-SHIP%  ^| Checking Version Info..
   FOR /F "tokens=2 delims==" %%i in ('TYPE %Found%verchk.bat ^|FINDSTR /B /C:"     SET ScriptVersion"') do SET VerChk-VER=%%i

   IF NOT "%VerChk-VER%."=="%VerChk-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
     SET "VerChk-VER=%VerChk-VER%"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-VerChk

   ECHO VerChk.bat   ^| %VerChk-SHIP%  ^| %VerChk-VER%  ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing SOFTRACK_CONSOLE.exe          *
   REM *****************************************
   SET Found=None
   SET SOFTRACK_CONSOLE-VER=
   IF EXIST SOFTRACK_FULL\SOFTRACK_CONSOLE.exe SET Found=SOFTRACK_FULL\
   IF EXIST SOFTRACK_CONSOLE.exe SET Found=.\

   IF "%Found%"=="None" (
     SET "SOFTRACK_CONSOLE-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-SOFTRACK_CONSOLE
   )

   IF NOT "%SilentMode%." =="Yes." ECHO CONSOLE.exe  ^| %SOFTRACK_CONSOLE-SHIP% ^| Checking Version Info..
   FOR /F "tokens=3 delims= " %%i in ('TYPE %found%SOFTRACK_CONSOLE.exe ^|FIND "7.4"') do SET SOFTRACK_CONSOLE-VER=v%%i

   REM for Components that predate internal rev strings
   IF "%SOFTRACK_CONSOLE-VER%."=="." SET SOFTRACK_CONSOLE-VER=V7.2xx

   IF NOT "%SOFTRACK_CONSOLE-VER%."=="%SOFTRACK_CONSOLE-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET SOFTRACK_CONSOLE-VER=%SOFTRACK_CONSOLE-VER%
     SET "VerResult=Yes"
   )

   :Skip-SOFTRACK_CONSOLE

   ECHO CONSOLE.exe  ^| %SOFTRACK_CONSOLE-SHIP% ^| %SOFTRACK_CONSOLE-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing DSRR4104.DLL                  *
   REM *****************************************
   SET Found=None
   SET DSRR4104-VER=
   IF EXIST SOFTRACK_FULL\DSRR4104.DLL SET Found=SOFTRACK_FULL\
   IF EXIST DSRR4104.DLL SET Found=.\

   IF "%Found%"=="None" (
     SET "DSRR4104-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-DSRR4104
   )

   IF NOT "%SilentMode%." =="Yes." ECHO DSRR4104.DLL ^| %DSRR4104-SHIP% ^| Checking Version Info..
   FOR /F "tokens=3 delims= " %%i in ('TYPE %found%DSRR4104.DLL ^|FIND /i "DSRR4104 Version"') do SET DSRR4104-VER=v%%i

   REM for components that predate internal rev strings
   IF "%DSRR4104-VER%."=="." SET "DSRR4104-VER=V1.00a"

   IF NOT "%DSRR4104-VER%."=="%DSRR4104-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-DSRR4104

   ECHO DSRR4104.DLL ^| %DSRR4104-SHIP% ^| %DSRR4104-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing QIADMIN.EXE                   *
   REM *****************************************
   SET Found=None
   SET QIADMIN-VER=
   IF EXIST SOFTRACK_FULL\QIADMIN.EXE SET "Found=SOFTRACK_FULL\"
   IF EXIST QIADMIN.EXE SET Found=.\

   IF "%Found%"=="None" (
     SET "QIADMIN-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-QIADMIN
   )

   IF NOT "%SilentMode%." =="Yes." ECHO QIADMIN.EXE  ^| %QIADMIN-SHIP% ^| Checking Version Info..
   FOR /F "tokens=2 delims= " %%i in ('TYPE %found%QIADMIN.EXE ^|FIND "Version 6."') do SET QIADMIN-VER=v%%i

   REM for Components that predate internal rev strings
   IF "%QIADMIN-VER%."=="." SET "QIADMIN-VER=V1.00a"

   IF NOT "%QIADMIN-VER%."=="%QIADMIN-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-QIADMIN

   ECHO QIADMIN.EXE  ^| %QIADMIN-SHIP% ^| %QIADMIN-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing STDLL32.DLL                   *
   REM *****************************************
   SET "Found=None"
   SET "STDLL32-VER="
   IF EXIST SOFTRACK_FULL\STDLL32.DLL SET "Found=SOFTRACK_FULL\"
   IF EXIST STDLL32.DLL SET Found=.\

   IF "%Found%"=="None" (
     SET "STDLL32-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STDLL32
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STDLL32.DLL  ^| %STDLL32-SHIP% ^| Checking Version Info..
   FOR /F "tokens=3 delims= " %%i in ('TYPE %found%STDLL32.DLL ^|FIND /i "STDLL32 Version"') do SET STDLL32-VER=v%%i

   REM for components that predate internal rev strings
   IF "%STDLL32-VER%."=="." SET "STDLL32-VER=V1.00a"

   IF NOT "%STDLL32-VER%."=="%STDLL32-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STDLL32

   ECHO STDLL32.DLL  ^| %STDLL32-SHIP% ^| %STDLL32-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing STNT32.DLL                    *
   REM *****************************************
   SET Found=None
   SET STNT32-VER=
   IF EXIST SOFTRACK_FULL\STNT32.DLL SET Found=SOFTRACK_FULL\
   IF EXIST STNT32.DLL SET Found=.\

   IF "%Found%"=="None" (
     SET "STNT32-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STNT32
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STNT32.DLL   ^| %STNT32-SHIP% ^| Checking Version Info..
   FOR /F "tokens=3 delims= " %%i in ('TYPE %found%STNT32.DLL ^|FIND /i "STNT32 Version"') do SET STNT32-VER=v%%i

   REM for Components that predate internal rev strings
   IF "%STNT32-VER%."=="." SET STNT32-VER=V1.00a

   IF NOT "%STNT32-VER%."=="%STNT32-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET STNT32-VER=%STNT32-VER%
     SET "VerResult=Yes"
   )

   :Skip-STNT32

   ECHO STNT32.DLL   ^| %STNT32-SHIP% ^| %STNT32-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing STAD0.DLL                     *
   REM *****************************************
   SET Found=None
   SET STAD0-VER-CON=
   IF EXIST SOFTRACK_FULL\STAD0.DLL SET Found=SOFTRACK_FULL\
   IF EXIST STAD0.DLL SET Found=.\

   IF "%Found%"=="None" (
     SET "STAD0-VER-CON=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STAD0-CON
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STAD0.DLL    ^| %STAD0-SHIP% ^| Checking Version Info..
   FOR /F "tokens=2 delims= " %%i in ('TYPE %found%STAD0.DLL ^|FIND /i "STAD0:Version"') do SET STAD0-VER-CON=v%%i

   REM for components that predate internal rev strings
   IF "%STAD0-VER-CON%."=="." SET STAD0-VER-CON=V1.00a

   IF NOT "%STAD0-VER-CON%."=="%STAD0-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STAD0-CON
   ECHO STAD0.DLL    ^| %STAD0-SHIP% ^| %STAD0-VER-CON% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )


   :NoTestConsole
REM                                                                     /
REM ********************************************************************

REM ****************************************************
REM * SSA Components Testing                           *
REM ********************************************************************
REM                                                                     \
   IF "%TestSSA%"=="No" GOTO NoTestSSA

   ECHO. >>%CreateBuild%
   ECHO SSA Component Versions: >>%CreateBuild%
   ECHO ---------------------------------------+>>%CreateBuild%
   ECHO Component    ^| Ref    ^| Found  ^|Pass ^|Path >>%CreateBuild%
   ECHO ---------------+--------+--------+-----+--------------------------------- >>%CreateBuild%

   ECHO. >>%TEMP%\VerChk-Header.tmp
   ECHO SSA Component Versions: >>%TEMP%\VerChk-Header.tmp
   ECHO ---------------------------------------+>>%TEMP%\VerChk-Header.tmp
   ECHO Component    ^| Ref    ^| Found  ^|Pass ^|Path >>%TEMP%\VerChk-Header.tmp
   ECHO -------------+--------+--------+-----+--------------------------------- >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing STSRVC.EXE NT4                *
   REM *****************************************
   SET Found=None
   SET STSRVC32-VER=
   IF EXIST %SystemRoot%\system32\drivers\STSRVC.EXE SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\drivers\STSRVC.EXE SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST SOFTRACK_FULL\NT4\STSRVC.EXE SET Found=SOFTRACK_FULL\NT4\
   IF EXIST NT4\STSRVC.EXE SET Found=NT4\
   IF EXIST STSRVC.EXE SET Found=.\

   IF "%Found%"=="None" (
     SET "STSRVC32-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STSRVC32b
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| Checking Version Info..
   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STSRVC.EXE ^|FIND "Windows v"') do SET STSRVC32-VER=%%i

   REM for components that predate internal rev strings
   IF "%STSRVC32-VER%."=="." SET STSRVC32-VER=V1.00a

   IF NOT "%STSRVC32-VER%."=="%STSRVC32-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STSRVC32b

   ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| %STSRVC32-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| %STSRVC32-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing STSRVC.EXE W2K                *
   REM *****************************************
   SET Found=None
   SET STSRVC32-VER=
   IF EXIST %SystemRoot%\system32\drivers\STSRVC.EXE SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\drivers\STSRVC.EXE SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST SOFTRACK_FULL\W2K\STSRVC.EXE SET Found=SOFTRACK_FULL\W2K\
   IF EXIST W2K\STSRVC.EXE SET Found=W2K\
   IF EXIST STSRVC.EXE SET Found=.\

   IF "%Found%"=="None" (
     SET "STSRVC32-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STSRVC32a
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| Checking Version Info..
   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STSRVC.EXE ^|FIND "Windows v"') do SET STSRVC32-VER=%%i

   REM for components that predate internal rev strings
   IF "%STSRVC32-VER%."=="." SET STSRVC32-VER=V1.00a

   IF NOT "%STSRVC32-VER%."=="%STSRVC32-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STSRVC32a

   ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| %STSRVC32-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| %STSRVC32-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )
   
   REM *****************************************
   REM * Testing STSRVC.EXE X64                *
   REM *****************************************
   SET Found=None
   SET STSRVC32-VER=
   IF EXIST %SystemRoot%\system32\drivers\STSRVC.EXE SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\drivers\STSRVC.EXE SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST %SystemRoot%\system32\STSRVC.EXE SET Found=%SystemRoot%\system32\
   IF EXIST %SystemRoot%\syswow64\STSRVC.EXE SET Found=%SystemRoot%\syswow64\
   IF EXIST SOFTRACK_FULL\X64\STSRVC.EXE SET Found=SOFTRACK_FULL\X64\
   IF EXIST W2K\STSRVC.EXE SET Found=X64\
   IF EXIST STSRVC.EXE SET Found=.\

   IF "%Found%"=="None" (
     SET "STSRVC32-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STSRVC32a
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| Checking Version Info..
   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STSRVC.EXE ^|FIND "Windows v"') do SET STSRVC32-VER=%%i

   REM for components that predate internal rev strings
   IF "%STSRVC32-VER%."=="." SET STSRVC32-VER=V1.00a

   IF NOT "%STSRVC32-VER%."=="%STSRVC32-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STSRVC32a

   ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| %STSRVC32-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STSRVC.EXE   ^| %STSRVC32-SHIP% ^| %STSRVC32-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )
   REM *****************************************
   REM * Testing 64 bit STSRVC64.EXE             *
   REM *****************************************
   SET Found=None
   SET STSRVC64-VER=
   IF EXIST %SystemRoot%\syswow64\drivers\STSRVC64.EXE SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST %SystemRoot%\syswow64\STSRVC64.EXE SET Found=%SystemRoot%\syswow64\
   IF EXIST SOFTRACK_FULL\X64\STSRVC64.EXE SET found=SOFTRACK_FULL\X64\
   IF EXIST X64\STSRVC64.EXE SET found=X64\
   IF EXIST STSRVC64.EXE SET found=.\

   IF "%Found%"=="None" (
     SET "STSRVC64-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STSRVC64
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STSRVC64.EXE   ^| %STSRVC64-SHIP% ^| Checking Version Info..
   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STSRVC64.EXE ^|FIND "Windows v"') do SET STSRVC64-VER=%%i

   REM for components that predate internal rev strings
   IF "%STSRVC64-VER%."=="." SET STSRVC64-VER=V1.00a

   IF NOT "%STSRVC64-VER%."=="%STSRVC64-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STSRVC64
   ECHO STSRVC64.EXE ^| %STSRVC64-SHIP% ^| %STSRVC64-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STSRVC64.EXE ^| %STSRVC64-SHIP% ^| %STSRVC64-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing STVIEW2K.SYS                  *
   REM *****************************************
   SET Found=None
   SET STVIEW2K-VER=
   IF EXIST %SystemRoot%\system32\drivers\STVIEW2K.SYS SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\drivers\STVIEW2K.SYS SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST SOFTRACK_FULL\W2K\STVIEW2K.SYS SET Found=SOFTRACK_FULL\W2K\
   IF EXIST W2K\STVIEW2K.SYS SET Found=W2K\
   IF EXIST STVIEW2K.SYS SET Found=.\

   IF "%Found%"=="None" (
     SET "STVIEW2K-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STVIEW2K
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STVIEW2K.SYS ^| %STVIEW2K-SHIP% ^| Checking Version Info..
   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STVIEW2K.SYS ^|FIND "Kernel Driver is v"') do SET STVIEW2K-VER=%%i

   REM for components that predate internal rev strings
   IF "%STVIEW2K-VER%."=="." SET STVIEW2K-VER=V1.00a

   IF NOT "%STVIEW2K-VER%."=="%STVIEW2K-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STVIEW2K

   ECHO STVIEW2K.SYS ^| %STVIEW2K-SHIP% ^| %STVIEW2K-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STVIEW2K.SYS ^| %STVIEW2K-SHIP% ^| %STVIEW2K-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing 64 bit STVIEW64.SYS           *
   REM *****************************************
   SET found=None
   SET STVIEW64-VER=
   IF EXIST %SystemRoot%\system32\drivers\STVIEW64.sys SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\system32\STVIEW64.sys SET Found=%SystemRoot%\system32\
   IF EXIST SOFTRACK_FULL\X64\STVIEW64.SYS SET found=SOFTRACK_FULL\X64\
   IF EXIST X64\STVIEW64.sys SET found=X64\
   IF EXIST STVIEW64.sys SET found=.\

   IF "%Found%"=="None" (
     SET "STVIEW64-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STSRVC
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STVIEW64.SYS ^| %STVIEW64-SHIP% ^| Checking Version Info..
   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STVIEW64.SYS ^|FIND "Kernel Driver is v"') do SET STVIEW64-VER=%%i

   REM for components that predate internal rev strings
   IF "%STVIEW64-VER%."=="." SET STVIEW64-VER=V1.00a

   IF NOT "%STVIEW64-VER%."=="%STVIEW64-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STSRVC
   ECHO STVIEW64.SYS ^| %STVIEW64-SHIP% ^| %STVIEW64-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STVIEW64.SYS ^| %STVIEW64-SHIP% ^| %STVIEW64-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )
   
   REM *****************************************
   REM * Testing STAD0.DLL SSA32      W2K      *
   REM *****************************************
   SET Found=None
   SET STAD0-VER-SSA32=
   IF EXIST %SystemRoot%\system32\drivers\STAD0.DLL SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\drivers\STAD0.DLL SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST SOFTRACK_FULL\W2K\STAD0.DLL SET Found=SOFTRACK_FULL\W2K\
   IF EXIST W2K\STAD0.DLL SET Found=W2K\
   
    IF "%Found%"=="None" (
     SET "STAD0-VER-SSA32=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STAD0-SSA32
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STAD0.DLL    ^| %STAD0-SHIP% ^| Checking Version Info..
   FOR /F "tokens=2 delims= " %%i in ('TYPE %found%STAD0.DLL ^|FIND /i "STAD0:Version"') do SET STAD0-VER-SSA32=v%%i

   REM for components that predate internal rev strings
   IF "%STAD0-VER-SSA32%."=="." SET STAD0-VER-SSA32=V1.00a

   IF NOT "%STAD0-VER-SSA32%."=="%STAD0-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STAD0-SSA32
   ECHO STAD0.DLL    ^| %STAD0-SHIP% ^| %STAD0-VER-SSA32% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STAD0.DLL    ^| %STAD0-SHIP% ^| %STAD0-VER-SSA32% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )
   
   REM *****************************************
   REM * Testing STAD0.DLL SSA32     NT4       *
   REM *****************************************
   SET Found=None
   SET STAD0-VER-SSA32=
   IF EXIST SOFTRACK_FULL\NT4\STAD0.DLL SET Found=SOFTRACK_FULL\NT4\
   IF EXIST NT4\STAD0.DLL SET Found=NT4\
   
    IF "%Found%"=="None" (
     SET "STAD0-VER-SSA32=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STAD0-SSA32
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STAD0.DLL    ^| %STAD0-SHIP% ^| Checking Version Info..
   FOR /F "tokens=2 delims= " %%i in ('TYPE %found%STAD0.DLL ^|FIND /i "STAD0:Version"') do SET STAD0-VER-SSA32=v%%i

   REM for components that predate internal rev strings
   IF "%STAD0-VER-SSA32%."=="." SET STAD0-VER-SSA32=V1.00a

   IF NOT "%STAD0-VER-SSA32%."=="%STAD0-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STAD0-SSA32
   ECHO STAD0.DLL    ^| %STAD0-SHIP% ^| %STAD0-VER-SSA32% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STAD0.DLL    ^| %STAD0-SHIP% ^| %STAD0-VER-SSA32% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing STAD0_64.DLL SSA64            *
   REM *****************************************
   SET Found=None
   SET STAD0_64-VER-SSA64=
   IF EXIST %SystemRoot%\system32\drivers\STAD0_64.DLL SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\drivers\STAD0_64.DLL SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST %SystemRoot%\syswow64\STAD0_64.DLL SET Found=%SystemRoot%\syswow64\
   IF EXIST SOFTRACK_FULL\X64\STAD0_64.DLL SET Found=SOFTRACK_FULL\X64\
   IF EXIST X64\STAD0_64.DLL SET Found=X64\
   IF EXIST STAD0_64.DLL SET Found=.\

    IF "%Found%"=="None" (
     SET "STAD0_64-VER-SSA64=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-STAD0_64-SSA64
   )

   IF NOT "%SilentMode%." =="Yes." ECHO STAD0_64.DLL    ^| %STAD0_64-SHIP% ^| Checking Version Info..
   FOR /F "tokens=2 delims= " %%i in ('TYPE %found%STAD0_64.DLL^|FIND /i "STAD0_64:Version"') do SET STAD0_64-VER-SSA64=v%%i

   REM for components that predate internal rev strings
   IF "%STAD0_64-VER-SSA64%."=="." SET STAD0_64-VER-SSA64=V1.00a

   IF NOT "%STAD0_64-VER-SSA64%."=="%STAD0_64-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-STAD0_64-SSA64
   ECHO STAD0_64.DLL ^| %STAD0_64-SHIP% ^| %STAD0_64-VER-SSA64% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO STAD0_64.DLL ^| %STAD0_64-SHIP% ^| %STAD0_64-VER-SSA64% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing SOFTRACK.NLM NLM5             *
   REM *****************************************
   SET Found=None
   SET SOFTRACK-NLM5-VER=
   IF EXIST SOFTRACK_FULL\NLM5\SOFTRACK.NLM SET Found=SOFTRACK_FULL\NLM5\
   IF EXIST NLM5\SOFTRACK.NLM SET Found=NLM5\
   IF EXIST SOFTRACK.NLM SET Found=.\

    IF "%Found%"=="None" (
     SET "SOFTRACK-NLM5-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-SOFTRACK-NLM5
   )

   IF NOT "%SilentMode%." =="Yes." ECHO SOFTRACK.NLM ^| %SOFTRACK-NLM5-SHIP% ^| Checking Version Info..
   FOR /F "tokens=5 delims= " %%i in ('TYPE %found%SOFTRACK.NLM ^|FIND "Software Metering NLM"') do SET SOFTRACK-NLM5-VER=%%i

   REM for components that predate internal rev strings
   IF "%SOFTRACK-NLM5-VER%."=="." SET SOFTRACK-NLM5-VER=V1.00a

   IF NOT "%SOFTRACK-NLM5-VER%."=="%SOFTRACK-NLM5-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-SOFTRACK-NLM5
   ECHO SOFTRACK.NLM ^| %SOFTRACK-NLM5-SHIP% ^| %SOFTRACK-NLM5-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO SOFTRACK.NLM   ^| %SOFTRACK-NLM5-SHIP% ^| %SOFTRACK-NLM5-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing ST2K_RPT.EXE                  *
   REM *****************************************
   SET found=None
   SET ST2K_RPT-VER=
   IF EXIST %SystemRoot%\system32\drivers\ST2K_RPT.EXE SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\ST2K_RPT.EXE SET Found=%SystemRoot%\syswow64\
   IF EXIST SOFTRACK_FULL\TOOLS\NT-2K\ST2K_RPT.EXE SET found=SOFTRACK_FULL\TOOLS\NT-2K\
   IF EXIST TOOLS\NT-2K\ST2K_RPT.EXE SET found=TOOLS\NT-2K\
   IF EXIST ST2K_RPT.EXE SET found=.\

   IF "%Found%"=="None" (
     SET "ST2K_RPT-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-ST2K_RPT
   )

   IF NOT "%SilentMode%." =="Yes." ECHO ST2K_RPT.EXE ^| %ST2K_RPT-SHIP% ^| Checking Version Info..
   FOR /F "tokens=11 delims= " %%i in ('%found%ST2K_RPT -help ^| FIND "Version "') do SET ST2K_RPT-VER=v%%i

   REM for components that predate internal rev strings
   IF "%ST2K_RPT-VER%."=="." SET ST2K_RPT-VER=V1.00a

   IF NOT "%ST2K_RPT-VER%."=="%ST2K_RPT-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-ST2K_RPT
   ECHO ST2K_RPT.EXE ^| %ST2K_RPT-SHIP% ^| %ST2K_RPT-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   
:NoTestSSA
REM                                                                     /
REM ********************************************************************

REM ****************************************************
REM * LWA Components Testing                           *
REM ********************************************************************
REM                                                                     \
REM   IF "%TestLWA%"=="No" GOTO NoTestLWA

REM   ECHO. >>%CreateBuild%
REM   ECHO LWA Component Versions: >>%CreateBuild%
REM   ECHO -------------------------------------+>>%CreateBuild%
REM   ECHO Component    ^| Ref    ^| Found  ^|Pass ^|Path >>%CreateBuild%
REM   ECHO -------------+--------+--------+-----+--------------------------------- >>%CreateBuild%

REM   ECHO. >>%TEMP%\VerChk-Header.tmp
REM   ECHO LWA Component Versions: >>%TEMP%\VerChk-Header.tmp
REM   ECHO -------------------------------------+>>%TEMP%\VerChk-Header.tmp
REM   ECHO Component    ^| Ref    ^| Found  ^|Pass ^|Path >>%TEMP%\VerChk-Header.tmp
REM   ECHO -------------+--------+--------+-----+--------------------------------- >>%TEMP%\VerChk-Header.tmp

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing LWA-QIA-Update.bat            *
   REM *****************************************
REM   SET Found=None
REM   IF EXIST %SystemDrive%\PROGRA~1\INTEGR~1\LWA-QIA-Update.bat SET Found=%SystemDrive%\PROGRA~1\INTEGR~1\
REM   IF EXIST %SystemDrive%\PROGRA~1\INTEGR~1\WORKST~1\LWA-QIA-Update.bat SET Found=%SystemDrive%\PROGRA~1\INTEGR~1\WORKST~1\
REM   IF EXIST SOFTRACK_FULL\LWA-QIA-Update.bat SET Found=SOFTRACK_FULL\
REM   IF EXIST LWA-QIA-Update.bat SET Found=.\

REM   IF "%Found%"=="None" (
REM     SET "LWA-QIA-Update-VER=N/A  "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-LWA-QIA-Update
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO LWA-QIA-updat^| %LWA-QIA-Update-SHIP%  ^| Checking Version Info..
REM   FOR /F "tokens=2 delims==" %%i in ('TYPE %Found%LWA-QIA-Update.bat ^|FINDSTR /B /C:"     SET ScriptVersion"') do SET LWA-QIA-Update-VER=v%%i

REM   IF NOT "%LWA-QIA-Update-VER%."=="%LWA-QIA-Update-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-LWA-QIA-Update

REM   ECHO LWA-QIA-updat^| %LWA-QIA-Update-SHIP%  ^| %LWA-QIA-Update-VER%  ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO LWA-QIA-updat^| %LWA-QIA-Update-SHIP%  ^| %LWA-QIA-Update-VER%  ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )


   REM *****************************************
   REM * Testing STLWA_NT.EXE                  *
   REM *****************************************
REM   SET found=None
REM   SET STLWA_NT-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\stlwa_nt.exe SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\stlwa_nt.exe SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\lwa.raw\nt-2k-xp\stlwa_nt.exe SET found=SOFTRACK_FULL\tools\lwa.raw\nt-2k-xp\
REM   IF EXIST tools\lwa.raw\nt-2k-xp\stlwa_nt.exe SET found=tools\lwa.raw\nt-2k-xp\
REM   IF EXIST stlwa_nt.exe SET found=.\

REM   IF "%Found%"=="None" (
REM     SET "STLWA_NT-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-STLWA_NT
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO STLWA_NT.EXE ^| %STLWA_NT-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=2 delims= " %%i in ('%found%stlwa_nt -profiles 2^>nul ^|FIND "Version"') do SET STLWA_NT-VER=v%%i

   REM for components that predate internal rev strings
REM   IF "%STLWA_NT-VER%."=="." SET STLWA_NT-VER=V1.00a

REM   IF NOT "%STLWA_NT-VER%."=="%STLWA_NT-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-STLWA_NT
REM   ECHO STLWA_NT.EXE ^| %STLWA_NT-SHIP% ^| %STLWA_NT-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO STLWA_NT.EXE ^| %STLWA_NT-SHIP% ^| %STLWA_NT-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing LWATRAY.EXE                  *
   REM *****************************************
REM   SET found=None
REM   SET LWATRAY-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\LWATRAY.EXE SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\LWATRAY.EXE SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\lwa.raw\nt-2k-xp\LWATRAY.EXE SET found=SOFTRACK_FULL\tools\lwa.raw\nt-2k-xp\
REM   IF EXIST tools\lwa.raw\nt-2k-xp\LWATRAY.EXE SET found=tools\lwa.raw\nt-2k-xp\
REM   IF EXIST LWATRAY.EXE SET found=.\

REM   IF "%Found%"=="None" (
REM     SET "LWATRAY-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-LWATRAY
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO LWATRAY.EXE   ^| %LWATRAY-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=2 delims==" %%i in ('TYPE %found%LWATRAY.EXE ^|FIND "LWATrayVersion="') do SET LWATRAY-VER=v%%i

   REM for components that predate internal rev strings
REM   IF "%LWATRAY-VER%."=="." SET LWATRAY-VER=v1.00a

REM   IF NOT "%LWATRAY-VER%."=="%LWATRAY-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-LWATRAY
REM   ECHO LWATRAY.EXE  ^| %LWATRAY-SHIP% ^| %LWATRAY-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO LWATRAY.EXE  ^| %LWATRAY-SHIP% ^| %LWATRAY-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing STLWMON.SYS                   *
   REM *****************************************
REM   SET found=None
REM   SET STLWMON-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\STLWMON.SYS SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\STLWMON.SYS SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\STLWMON.SYS SET found=SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\
REM   IF EXIST tools\LWA.raw\nt-2k-xp\STLWMON.SYS SET found=tools\LWA.raw\nt-2k-xp\
REM   IF EXIST STLWMON.SYS SET found=.\

REM   IF "%Found%"=="None" (
REM     SET "STLWMON-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-STLWMON
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO STLWMON.SYS  ^| %STLWMON-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STLWMON.SYS ^| FIND /i "STLWMON Kernel Driver"') do SET STLWMON-VER=%%i

   REM for components that predate internal rev strings
REM   IF "%STLWMON-VER%."=="." SET STLWMON-VER=V1.00a

REM   IF NOT "%STLWMON-VER%."=="%STLWMON-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-STLWMON
REM   ECHO STLWMON.SYS  ^| %STLWMON-SHIP% ^| %STLWMON-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO STLWMON.SYS  ^| %STLWMON-SHIP% ^| %STLWMON-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing STBW_K32.SYS                  *
   REM *****************************************
REM   SET Found=None
REM   SET STBW_K32-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\STBW_K32.SYS SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\STBW_K32.SYS SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\STBW_K32.SYS SET Found=SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\
REM   IF EXIST tools\LWA.raw\nt-2k-xp\STBW_K32.SYS SET Found=tools\LWA.raw\nt-2k-xp\
REM   IF EXIST STBW_K32.SYS SET Found=.\

REM   IF "%Found%"=="None" (
REM     SET "STBW_K32-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-STBW_K32
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO STBW_K32.SYS ^| %STBW_K32-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STBW_K32.SYS ^|FIND "Kernel Driver is v"') do SET STBW_K32-VER=%%i

   REM for components that predate internal rev strings
REM   IF "%STBW_K32-VER%."=="." SET STBW_K32-VER=V1.00a

REM   IF NOT "%STBW_K32-VER%."=="%STBW_K32-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-STBW_K32

REM   ECHO STBW_K32.SYS ^| %STBW_K32-SHIP% ^| %STBW_K32-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO STBW_K32.SYS ^| %STBW_K32-SHIP% ^| %STBW_K32-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing CPTLWA32.DLL                  *
   REM *****************************************
REM   SET found=None
REM   SET CPTLWA32-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\CPTLWA32.DLL SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\CPTLWA32.DLL SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\CPTLWA32.DLL SET found=SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\
REM   IF EXIST tools\LWA.raw\nt-2k-xp\CPTLWA32.DLL SET found=tools\LWA.raw\nt-2k-xp\
REM   IF EXIST CPTLWA32.DLL SET found=.\

REM   IF "%Found%"=="None" (
REM     SET "CPTLWA32-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-CPTLWA32
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO CPTLWA32.DLL ^| %CPTLWA32-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=3 delims= " %%i in ('TYPE %found%CPTLWA32.DLL ^| FIND "CPTLWA32 Version"') do SET CPTLWA32-VER=v%%i

   REM for components that predate internal rev strings
REM   IF "%CPTLWA32-VER%."=="." SET CPTLWA32-VER=V1.00a

REM   IF NOT "%CPTLWA32-VER%."=="%CPTLWA32-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-CPTLWA32
REM   ECHO CPTLWA32.DLL ^| %CPTLWA32-SHIP% ^| %CPTLWA32-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO CPTLWA32.DLL ^| %CPTLWA32-SHIP% ^| %CPTLWA32-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing STVISTA.SYS                   *
   REM *****************************************
REM   SET found=None
REM   SET STVISTA-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\STVISTA.SYS SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\STVISTA.SYS SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\STVISTA.SYS SET found=SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\
REM   IF EXIST tools\LWA.raw\nt-2k-xp\STVISTA.SYS SET found=tools\LWA.raw\nt-2k-xp\
REM   IF EXIST STVISTA.SYS SET found=.\

REM     IF "%Found%"=="None" (
REM     SET "STVISTA-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-STVISTA
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO STVISTA.SYS  ^| %STVISTA-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STVISTA.SYS ^| FIND "STVISTA Kernel Driver"') do SET STVISTA-VER=%%i

   REM for components that predate internal rev strings
REM   IF "%STVISTA-VER%."=="." SET STVISTA-VER=V1.00a

REM   IF NOT "%STVISTA-VER%."=="%STVISTA-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-STVISTA
REM   ECHO STVISTA.SYS  ^| %STVISTA-SHIP% ^| %STVISTA-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO STVISTA.SYS  ^| %STVISTA-SHIP% ^| %STVISTA-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing STBW_K64.SYS                  *
   REM *****************************************
REM   SET Found=None
REM   SET STBW_K64-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\STBW_K64.SYS SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\STBW_K64.SYS SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\STBW_K64.SYS SET Found=SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\
REM   IF EXIST tools\LWA.raw\nt-2k-xp\STBW_K64.SYS SET Found=tools\LWA.raw\nt-2k-xp\
REM   IF EXIST STBW_K64.SYS SET Found=.\

REM   IF "%Found%"=="None" (
REM     SET "STBW_K64-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-STBW_K64
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO STBW_K64.SYS ^| %STBW_K64-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=4 delims= " %%i in ('TYPE %found%STBW_K64.SYS ^|FIND "Kernel Driver is v"') do SET STBW_K64-VER=%%i

   REM for components that predate internal rev strings
REM   IF "%STBW_K64-VER%."=="." SET STBW_K64-VER=V1.00a

REM   IF NOT "%STBW_K64-VER%."=="%STBW_K64-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-STBW_K64

REM   ECHO STBW_K64.SYS ^| %STBW_K64-SHIP% ^| %STBW_K64-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO STBW_K64.SYS ^| %STBW_K64-SHIP% ^| %STBW_K64-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing STLWA_64.SYS                  *
   REM *****************************************
REM   SET found=None
REM   SET STLWA_64-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\STLWA_64.SYS SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\STLWA_64.SYS SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\STLWA_64.SYS SET found=SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\
REM   IF EXIST tools\LWA.raw\nt-2k-xp\STLWA_64.SYS SET found=tools\LWA.raw\nt-2k-xp\
REM   IF EXIST STLWA_64.SYS SET found=.\

REM   IF "%Found%"=="None" (
REM     SET "STLWA_64-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-STLWA_64
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO STLWA_64.SYS ^| %STLWA_64-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=5 delims= " %%i in ('TYPE %found%STLWA_64.SYS ^| FIND "STLWA_64 Kernel Driver"') do SET STLWA_64-VER=%%i

   REM for components that predate internal rev strings
REM   IF "%STLWA_64-VER%."=="." SET STLWA_64-VER=V1.00a

REM   IF NOT "%STLWA_64-VER%."=="%STLWA_64-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-STLWA_64
REM   ECHO STLWA_64.SYS ^| %STLWA_64-SHIP% ^| %STLWA_64-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO STLWA_64.SYS ^| %STLWA_64-SHIP% ^| %STLWA_64-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing CPTLWA64.DLL                  *
   REM *****************************************
REM   SET found=None
REM   SET CPTLWA64-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\CPTLWA64.DLL SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\CPTLWA64.DLL SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\CPTLWA64.DLL SET found=SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\
REM   IF EXIST tools\LWA.raw\nt-2k-xp\CPTLWA64.DLL SET found=tools\LWA.raw\nt-2k-xp\
REM   IF EXIST CPTLWA64.DLL SET found=.\

REM   IF "%Found%"=="None" (
REM     SET "CPTLWA64-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-CPTLWA64
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO CPTLWA64.DLL ^| %CPTLWA64-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=3 delims= " %%i in ('TYPE %found%CPTLWA64.DLL ^| FIND "CPTLWA64 Version"') do SET CPTLWA64-VER=v%%i

   REM for components that predate internal rev strings
REM   IF "%CPTLWA64-VER%."=="." SET CPTLWA64-VER=V1.00a

REM   IF NOT "%CPTLWA64-VER%."=="%CPTLWA64-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-CPTLWA64
REM   ECHO CPTLWA64.DLL ^| %CPTLWA64-SHIP% ^| %CPTLWA64-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO CPTLWA64.DLL ^| %CPTLWA64-SHIP% ^| %CPTLWA64-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )

   REM *****************************************
   REM * Testing CPT_X64A.EXE                  *
   REM *****************************************
REM   SET found=None
REM   SET CPT_X64A-VER=
REM   IF EXIST %SystemRoot%\system32\drivers\CPT_X64A.EXE SET Found=%SystemRoot%\system32\drivers\
REM   IF EXIST %SystemRoot%\syswow64\drivers\CPT_X64A.EXE SET Found=%SystemRoot%\syswow64\drivers\
REM   IF EXIST SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\CPT_X64A.EXE SET found=SOFTRACK_FULL\tools\LWA.raw\nt-2k-xp\
REM   IF EXIST tools\LWA.raw\nt-2k-xp\CPT_X64A.EXE SET found=tools\LWA.raw\nt-2k-xp\
REM   IF EXIST CPT_X64A.EXE SET found=.\

REM   IF "%Found%"=="None" (
REM     SET "CPT_X64A-VER=N/A   "
REM     SET "Found=     "
REM     SET "VerResult=   "
REM     Goto Skip-CPT_X64A
REM   )

REM   IF NOT "%SilentMode%." =="Yes." ECHO CPT_X64A.EXE ^| %CPT_X64A-SHIP% ^| Checking Version Info..
REM   FOR /F "tokens=3 delims= " %%i in ('TYPE %found%CPT_X64A.EXE ^| FIND "CPT_X64A Version"') do SET CPT_X64A-VER=v%%i

   REM for components that predate internal rev strings
REM   IF "%CPT_X64A-VER%."=="." SET CPT_X64A-VER=V1.00a

REM   IF NOT "%CPT_X64A-VER%."=="%CPT_X64A-SHIP%." (
REM     SET "VerResult=No "
REM     SET "VerChkResult=MISMATCH"
REM   ) ELSE (
REM     SET "VerResult=Yes"
REM   )

REM   :Skip-CPT_X64A
REM   ECHO CPT_X64A.EXE ^| %CPT_X64A-SHIP% ^| %CPT_X64A-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
REM   ECHO CPT_X64A.EXE ^| %CPT_X64A-SHIP% ^| %CPT_X64A-VER% ^| %VerResult% ^| %found% >>%CreateBuild%

REM   IF NOT "%SilentMode%." =="Yes." (
REM     CLS
REM     TYPE %TEMP%\VerChk-Header.tmp
REM   )
REM   :NoTestLWA
REM                                                                     /
REM ********************************************************************

REM ****************************************************
REM * Testing QIA components                           *
REM ********************************************************************
REM                                                                     \
   IF "%TestQIA%"=="No" GOTO NoTestQIA

   ECHO. >>%CreateBuild%
   ECHO QIA Component Versions: >>%CreateBuild%
   ECHO -------------------------------------+>>%CreateBuild%
   ECHO Component    ^| Ref    ^| Found  ^|Pass ^|Path >>%CreateBuild%
   ECHO -------------+--------+--------+-----+--------------------------------- >>%CreateBuild%

   ECHO. >>%TEMP%\VerChk-Header.tmp
   ECHO QIA Component Versions: >>%TEMP%\VerChk-Header.tmp
   ECHO -------------------------------------+>>%TEMP%\VerChk-Header.tmp
   ECHO Component    ^| Ref    ^| Found  ^|Pass ^|Path >>%TEMP%\VerChk-Header.tmp
   ECHO -------------+--------+--------+-----+--------------------------------- >>%TEMP%\VerChk-Header.tmp
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing INVENTRY.EXE                  *
   REM *****************************************
   SET found=None
   SET INVENTRY-VER=
   IF EXIST %SystemRoot%\system32\drivers\INVENTRY.EXE SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\drivers\INVENTRY.EXE SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST SOFTRACK_FULL\tools\QIA.raw\INVENTRY.EXE SET found=SOFTRACK_FULL\tools\QIA.raw\
   IF EXIST tools\QIA.raw\INVENTRY.EXE SET found=tools\QIA.raw\
   IF EXIST INVENTRY.EXE SET found=.\

   IF "%Found%"=="None" (
     SET "INVENTRY-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-INVENTRY
   )

   IF NOT "%SilentMode%." =="Yes." ECHO INVENTRY.EXE ^| %INVENTRY-SHIP%  ^| Checking Version Info..
   FOR /F "tokens=5 delims= " %%i in ('TYPE %found%INVENTRY.EXE ^| FIND "SofTrack Quick Inventory Module"') do SET INVENTRY-VER=%%i

   REM for components that predate internal rev strings
   IF "%INVENTRY-VER%."=="." SET INVENTRY-VER=V1.00a

   IF NOT "%INVENTRY-VER%."=="%INVENTRY-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-INVENTRY
   ECHO INVENTRY.EXE ^| %INVENTRY-SHIP%  ^| %INVENTRY-VER%  ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO INVENTRY.EXE ^| %INVENTRY-SHIP%  ^| %INVENTRY-VER%  ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * Testing QISVC0.EXE                    *
   REM *****************************************
   SET found=None
   SET QISVC0-VER=
   IF EXIST SOFTRACK_FULL\tools\QIA.raw\QISVC0.EXE SET found=SOFTRACK_FULL\tools\QIA.raw\
   IF EXIST %SystemRoot%\system32\drivers\QISVC0.EXE SET Found=%SystemRoot%\system32\drivers\
   IF EXIST %SystemRoot%\syswow64\drivers\QISVC0.EXE SET Found=%SystemRoot%\syswow64\drivers\
   IF EXIST tools\QIA.raw\QISVC0.EXE SET found=tools\QIA.raw\
   IF EXIST QISVC0.EXE SET found=.\

   IF "%Found%"=="None" (
     SET "QISVC0-VER=N/A   "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-QISVC0
   )

   IF NOT "%SilentMode%." =="Yes." ECHO QISVC0.EXE   ^| %QISVC0-SHIP%  ^| Checking Version Info..
   FOR /F "tokens=5 delims= " %%i in ('%found%QISVC0.EXE -profiles 2^>nul ^| FIND "SofTrack Quick Inventory Service"') do SET QISVC0-VER=%%i

   REM for components that predate internal rev strings
   IF "%QISVC0-VER%."=="." SET QISVC0-VER=V1.00a

   IF NOT "%QISVC0-VER%."=="%QISVC0-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-QISVC0
   ECHO QISVC0.EXE   ^| %QISVC0-SHIP%  ^| %QISVC0-VER%  ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp
   ECHO QISVC0.EXE   ^| %QISVC0-SHIP%  ^| %QISVC0-VER%  ^| %VerResult% ^| %found% >>%CreateBuild%

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   :NoTestQIA
REM                                                                     /
REM ********************************************************************

REM ****************************************************
REM * Agent MSI version Testing                        *
REM ********************************************************************
REM                                                                     \
   IF "%TestMSI%"=="No" GOTO NoTestMSI

   ECHO. >>%TEMP%\VerChk-Header.tmp
   ECHO MSI Installer Versions: >>%TEMP%\VerChk-Header.tmp
   ECHO -------------------------------------------------+>>%TEMP%\VerChk-Header.tmp
   ECHO Component    ^| Ref          ^| Found        ^|Pass ^|Path>>%TEMP%\VerChk-Header.tmp
   ECHO -------------+--------------+--------------+-----+--------------------->>%TEMP%\VerChk-Header.tmp
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   REM *****************************************
   REM * LWASETUP.MSI                          *
   REM *****************************************
   SET found=None
   SET LWASETUP-VER=
   IF EXIST softrack_full\Install.LWA.and.QIA\LWASETUP.MSI SET found=softrack_full\Install.LWA.and.QIA\
   IF EXIST Install.LWA.and.QIA\LWASETUP.MSI SET found=Install.LWA.and.QIA\
   IF EXIST LWASETUP.MSI SET found=.\

   IF "%Found%"=="None" (
     SET "LWASETUP-VER=N/A         "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-LWASETUP
   )

   IF NOT "%SilentMode%." =="Yes." ECHO LWASETUP.MSI ^| %LWASETUP-SHIP% ^| Checking Version..
   FOR /F "tokens=4 delims= " %%i in ('type %found%LWASETUP.MSI ^| FIND "Enterprise Agent" ^|FIND /V "be"') do SET LWASETUP-VER=%%i

   REM for components that predate internal rev strings
   IF "%LWASETUP-VER%."=="." SET LWASETUP-VER=V1.00a

   IF NOT "%LWASETUP-VER%."=="%LWASETUP-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-LWASETUP
   ECHO LWASETUP.MSI ^| %LWASETUP-SHIP% ^| %LWASETUP-VER% ^| %VerResult% ^| %found%>>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )


   REM *****************************************
   REM * QIASETUP.MSI                          *
   REM *****************************************
   SET found=None
   SET QIASETUP-VER=
   IF EXIST softrack_full\Install.QIA.only\QIASETUP.MSI SET found=softrack_full\Install.QIA.only\
   IF EXIST Install.QIA.only\QIASETUP.MSI SET found=Install.QIA.only\
   IF EXIST QIASETUP.MSI SET found=.\

   IF "%Found%"=="None" (
     SET "QIASETUP-VER=N/A         "
     SET "Found=     "
     SET "VerResult=   "
     Goto Skip-QIASETUP
   )

   IF NOT "%SilentMode%." =="Yes." ECHO QIASETUP.MSI ^| %QIASETUP-SHIP% ^| Checking Version..
   FOR /F "tokens=4 delims= " %%i in ('type %found%QIASETUP.MSI ^| FIND "Inventory Agent" ^|FIND /V "[ProductName]"') do SET QIASETUP-VER=%%i

   REM for components that predate internal rev strings
   IF "%QIASETUP-VER%."=="." SET QIASETUP-VER=V1.00a

   IF NOT "%QIASETUP-VER%."=="%QIASETUP-SHIP%." (
     SET "VerResult=No "
     SET "VerChkResult=MISMATCH"
   ) ELSE (
     SET "VerResult=Yes"
   )

   :Skip-QIASETUP
   ECHO QIASETUP.MSI ^| %QIASETUP-SHIP% ^| %QIASETUP-VER% ^| %VerResult% ^| %found% >>%TEMP%\VerChk-Header.tmp

   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

   :NoTestMSI
REM                                                                     /
REM ********************************************************************

REM ****************************************************
REM * VerChk complete                                  *
REM ****************************************************
   ECHO. >>%TEMP%\VerChk-Header.tmp
   ECHO ----------------------------------------------------------->>%TEMP%\VerChk-Header.tmp
   ECHO Components version match check: %VerChkResult% >>%TEMP%\VerChk-Header.tmp

   ECHO. >>%CreateBuild%
   ECHO Components version match check: %VerChkResult% >>%CreateBuild%

   IF NOT "%VerChkResult%"=="PASS" (
     REM If NOT pass go black text, yellow background
     IF NOT "%SilentMode%." =="Yes." COLOR E0
     ECHO ----------------------------------------------------------->>%TEMP%\VerChk-Header.tmp
     ECHO NOTICE: Please contact support for assistance>>%TEMP%\VerChk-Header.tmp
     ECHO         interpreting these results.>>%TEMP%\VerChk-Header.tmp
     ECHO         Email: support@softwaremetering.com>>%TEMP%\VerChk-Header.tmp
     ECHO         Phone: 1 512-372-8991 x2>>%TEMP%\VerChk-Header.tmp
     ECHO.         >>%TEMP%\VerChk-Header.tmp
   ) ELSE (
     ECHO ----------------------------------------------------------->>%TEMP%\VerChk-Header.tmp
     REM If pass, go black text, green background
     IF NOT "%SilentMode%." =="Yes." COLOR A0
   )
   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )




REM ****************************************************
REM * Output Results                                   *
REM ****************************************************
   SET VerChkLogPath=%CD%

   REM Remove trailing slash if present
   IF %VerChkLogPath:~-1%==\ SET VerChkLogPath=%VerChkLogPath:~0,-1%

   TYPE %TEMP%\VerChk-Header.tmp >"%VerChkLogPath%\VerChk.TXT"
   ECHO. >>%TEMP%\VerChk-Header.tmp
   ECHO Verchk results written to: >>%TEMP%\VerChk-Header.tmp
   ECHO "%VerChkLogPath%\VerChk.TXT" >>%TEMP%\VerChk-Header.tmp


   IF NOT "%SilentMode%." =="Yes." (
     CLS
     TYPE %TEMP%\VerChk-Header.tmp
   )

REM ****************************************************
REM * Writing CSV file result                          *
REM * NOTE: future enhancement!                        *
REM * Have to not append vars yet.. hmmm               *
REM ****************************************************
   rem ECHO.
   rem ECHO Writing CSV file..
   rem ECHO "Component","Version %Now%","Version"

REM ****************************************************
REM * Clean Up temp files                              *
REM ****************************************************
   :CleanUp
   DEL /Q %TEMP%\VerChk-Header.tmp %DEBUG%
   DEL /Q %temp%\FetchUpdate.vbs %DEBUG%

   IF NOT "%SilentMode%." =="Yes." (
     ECHO.
     PAUSE
     COLOR 0F
   )
   REM Set VerChkResult to exist after script exits
   ENDLOCAL & SET VerChkResult=%VerChkResult%
